@@ -18,13 +18,19 @@
 
 #include "lxqtbacklight.h"
 #include "lxqtbacklight/virtual_backend.h"
-#include "lxqtbacklight/linux_backend/linuxbackend.h"
+#ifdef USE_BACKLIGHT_LINUX_BACKEND
+    #include "lxqtbacklight/linux_backend/linuxbackend.h"
+#endif
 
 namespace LXQt {
 
 Backlight::Backlight(QObject *parent):QObject(parent)
 {
+#ifdef USE_BACKLIGHT_LINUX_BACKEND
     m_backend = (VirtualBackEnd *) new LinuxBackend(this);
+#else
+    m_backend = new VirtualBackEnd(this);
+#endif
     connect(m_backend, &VirtualBackEnd::backlightChanged, this, &Backlight::backlightChangedSlot);
 }
 
@@ -60,7 +66,7 @@ void Backlight::setBacklight(int value)
 
 void Backlight::backlightChangedSlot(int value)
 {
-    emit backlightChanged(value);
+    Q_EMIT backlightChanged(value);
 }
 
 } // namespace LXQt
