@@ -29,7 +29,7 @@ class LXQT_API VirtualBackEnd:public QObject
 Q_OBJECT
 
 public:    
-    VirtualBackEnd(QObject *parent = 0);
+    VirtualBackEnd(QObject *parent = nullptr);
    
     virtual bool isBacklightAvailable();
     virtual bool isBacklightOff();
@@ -37,10 +37,10 @@ public:
     virtual int getBacklight();
     virtual int getMaxBacklight();
     
-signals:
+Q_SIGNALS:
     void backlightChanged(int value);
 };
 
 } // namespace LXQt
 
-#endif  // __VirtualBackend_H__
\ No newline at end of file
+#endif  // __VirtualBackend_H__
