@@ -74,21 +74,21 @@ public:
     The layout has one row and zero column initially, and will
     expand to left when new items are inserted.
     **/
-    explicit GridLayout(QWidget *parent = 0);
+    explicit GridLayout(QWidget *parent = nullptr);
 
     /**
     Destroys the grid layout. The layout's widgets aren't destroyed.
      **/
-    ~GridLayout();
+    ~GridLayout() override;
 
-    void addItem(QLayoutItem *item);
-    QLayoutItem *itemAt(int index) const;
-    QLayoutItem *takeAt(int index);
-    int count() const;
-    void invalidate();
+    void addItem(QLayoutItem *item) override;
+    QLayoutItem *itemAt(int index) const override;
+    QLayoutItem *takeAt(int index) override;
+    int count() const override;
+    void invalidate() override;
 
-    QSize sizeHint() const;
-    void setGeometry(const QRect &geometry);
+    QSize sizeHint() const override;
+    void setGeometry(const QRect &geometry) override;
     QRect occupiedGeometry() const;
 
 
