@@ -48,14 +48,14 @@ public:
         DontCheckDBUS
     };
 
-    explicit PowerProvider(QObject *parent = 0);
-    virtual ~PowerProvider();
+    explicit PowerProvider(QObject *parent = nullptr);
+    ~PowerProvider() override;
 
     /*! Returns true if the Power can perform action.
         This is a pure virtual function, and must be reimplemented in subclasses. */
     virtual bool canAction(Power::Action action) const = 0 ;
 
-public slots:
+public Q_SLOTS:
     /*! Performs the requested action.
         This is a pure virtual function, and must be reimplemented in subclasses. */
     virtual bool doAction(Power::Action action) = 0;
@@ -66,12 +66,12 @@ class UPowerProvider: public PowerProvider
 {
     Q_OBJECT
 public:
-    UPowerProvider(QObject *parent = 0);
-    ~UPowerProvider();
-    bool canAction(Power::Action action) const;
+    UPowerProvider(QObject *parent = nullptr);
+    ~UPowerProvider() override;
+    bool canAction(Power::Action action) const override;
 
-public slots:
-    bool doAction(Power::Action action);
+public Q_SLOTS:
+    bool doAction(Power::Action action) override;
 };
 
 
@@ -79,12 +79,12 @@ class ConsoleKitProvider: public PowerProvider
 {
     Q_OBJECT
 public:
-    ConsoleKitProvider(QObject *parent = 0);
-    ~ConsoleKitProvider();
-    bool canAction(Power::Action action) const;
+    ConsoleKitProvider(QObject *parent = nullptr);
+    ~ConsoleKitProvider() override;
+    bool canAction(Power::Action action) const override;
 
-public slots:
-    bool doAction(Power::Action action);
+public Q_SLOTS:
+    bool doAction(Power::Action action) override;
 };
 
 
@@ -92,12 +92,12 @@ class SystemdProvider: public PowerProvider
 {
     Q_OBJECT
 public:
-    SystemdProvider(QObject *parent = 0);
-    ~SystemdProvider();
-    bool canAction(Power::Action action) const;
+    SystemdProvider(QObject *parent = nullptr);
+    ~SystemdProvider() override;
+    bool canAction(Power::Action action) const override;
 
-public slots:
-    bool doAction(Power::Action action);
+public Q_SLOTS:
+    bool doAction(Power::Action action) override;
 };
 
 
@@ -105,24 +105,24 @@ class LXQtProvider: public PowerProvider
 {
     Q_OBJECT
 public:
-    LXQtProvider(QObject *parent = 0);
-    ~LXQtProvider();
-    bool canAction(Power::Action action) const;
+    LXQtProvider(QObject *parent = nullptr);
+    ~LXQtProvider() override;
+    bool canAction(Power::Action action) const override;
 
-public slots:
-    bool doAction(Power::Action action);
+public Q_SLOTS:
+    bool doAction(Power::Action action) override;
 };
 
 class LxSessionProvider: public PowerProvider
 {
     Q_OBJECT
 public:
-    LxSessionProvider(QObject *parent = 0);
-    ~LxSessionProvider();
-    bool canAction(Power::Action action) const;
+    LxSessionProvider(QObject *parent = nullptr);
+    ~LxSessionProvider() override;
+    bool canAction(Power::Action action) const override;
 
-public slots:
-    bool doAction(Power::Action action);
+public Q_SLOTS:
+    bool doAction(Power::Action action) override;
 private:
     Q_PID pid;
 };
@@ -131,12 +131,12 @@ class HalProvider: public PowerProvider
 {
     Q_OBJECT
 public:
-    HalProvider(QObject *parent = 0);
-    ~HalProvider();
-    bool canAction(Power::Action action) const;
+    HalProvider(QObject *parent = nullptr);
+    ~HalProvider() override;
+    bool canAction(Power::Action action) const override;
 
-public slots:
-    bool doAction(Power::Action action);
+public Q_SLOTS:
+    bool doAction(Power::Action action) override;
 };
 
 
@@ -144,12 +144,12 @@ class CustomProvider: public PowerProvider
 {
     Q_OBJECT
 public:
-    CustomProvider(QObject *parent = 0);
-    ~CustomProvider();
-    bool canAction(Power::Action action) const;
+    CustomProvider(QObject *parent = nullptr);
+    ~CustomProvider() override;
+    bool canAction(Power::Action action) const override;
 
-public slots:
-    bool doAction(Power::Action action);
+public Q_SLOTS:
+    bool doAction(Power::Action action) override;
 
 private:
     Settings mSettings;
