@@ -538,11 +538,11 @@ QString LXQtTheme::desktopBackground(int screen) const
 
     s.setArrayIndex(screen - 1);
     if (s.contains(QL1S("file")))
-        return QString::fromLatin1("%1/%2").arg(themeDir, s.value(QL1S("file")).toString());
+        return QDir::cleanPath(QString::fromLatin1("%1/%2").arg(themeDir, s.value(QL1S("file")).toString()));
 
     s.setArrayIndex(0);
     if (s.contains(QL1S("file")))
-        return QString::fromLatin1("%1/%2").arg(themeDir, s.value(QL1S("file")).toString());
+        return QDir::cleanPath(QString::fromLatin1("%1/%2").arg(themeDir, s.value(QL1S("file")).toString()));
 
     return QString();
 }
@@ -621,6 +621,7 @@ SettingsCache::SettingsCache(QSettings *settings) :
  ************************************************/
 void SettingsCache::loadFromSettings()
 {
+    mCache.clear();
     const QStringList keys = mSettings.allKeys();
 
     const int N = keys.size();
